==> shardingsphere-database-protocol-postgresql-4.1.0-sources.jar: org/apache/shardingsphere/database/protocol/postgresql/packet/generic/PostgreSQLCommandCompletePacket.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.database.protocol.postgresql.packet.generic;

import lombok.Getter;
import org.apache.shardingsphere.database.protocol.postgresql.packet.PostgreSQLPacket;
import org.apache.shardingsphere.database.protocol.postgresql.packet.command.PostgreSQLCommandPacketType;
import org.apache.shardingsphere.database.protocol.postgresql.payload.PostgreSQLPacketPayload;

/**
 * Command complete packet for PostgreSQL.
 */
public final class PostgreSQLCommandCompletePacket implements PostgreSQLPacket {
    
    @Getter
    private final char messageType = PostgreSQLCommandPacketType.COMMAND_COMPLETE.getValue();
    
    private final String sqlCommand = "";
    
    private final int rowCount = 0;
    
    @Override
    public void write(final PostgreSQLPacketPayload payload) {
        // TODO payload.writeStringNul(sqlCommand + " " + rowCount);
        payload.writeStringNul("");
    }
}

==> shardingsphere-database-protocol-postgresql-4.1.1-sources.jar: org/apache/shardingsphere/database/protocol/postgresql/packet/generic/PostgreSQLCommandCompletePacket.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.database.protocol.postgresql.packet.generic;

import lombok.Getter;
import org.apache.shardingsphere.database.protocol.postgresql.packet.PostgreSQLPacket;
import org.apache.shardingsphere.database.protocol.postgresql.packet.command.PostgreSQLCommandPacketType;
import org.apache.shardingsphere.database.protocol.postgresql.payload.PostgreSQLPacketPayload;

/**
 * Command complete packet for PostgreSQL.
 */
public final class PostgreSQLCommandCompletePacket implements PostgreSQLPacket {
    
    @Getter
    private final char messageType = PostgreSQLCommandPacketType.COMMAND_COMPLETE.getValue();
    
    private final String sqlCommand;
    
    private final long rowCount;
    
    public PostgreSQLCommandCompletePacket() {
        sqlCommand = "";
        rowCount = 0;
    }
    
    public PostgreSQLCommandCompletePacket(final String sqlCommand, final long rowCount) {
        this.sqlCommand = sqlCommand;
        this.rowCount = rowCount;
    }
    
    @Override
    public void write(final PostgreSQLPacketPayload payload) {
        payload.writeStringNul(sqlCommand + " " + rowCount);
    }
}
